@@ -17,3 +17,6 @@
 /* Define if you have stpcpy.  */
 #undef HAVE_STPCPY
 
+#undef ENABLE_WHITE_BOARD
+
+#undef WINMX_QUEUE_BEHAVIOUR
