@@ -7,6 +7,9 @@ test -f configure.in || {
     exit 1
 }
 
+mv intl/CVS intlCVS 2>/dev/null
+gettextize -f
+mv intlCVS intl/CVS 2>/dev/null
 aclocal
 autoheader
 automake -a
