@@ -1,3 +1,7 @@
+/* Copyright (C) 2000/2001 sgop@users.sourceforge.net
+   This is free software distributed under the terms of the
+   GNU Public License.  See the file COPYING for details. */
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -47,10 +51,11 @@
 
 int exec_find_free_id();
 
-exec_t* exec_new(char* name) {
-  exec_t* exec;
+exec_t *exec_new(char *name)
+{
+  exec_t *exec;
 
-  exec = (exec_t*)malloc(sizeof(exec_t));
+  exec = (exec_t *) l_malloc(sizeof(exec_t));
   exec->input = -1;
   exec->output = O_WINDOW;
   exec->who = NULL;
@@ -58,14 +63,17 @@ exec_t* exec_new(char* name) {
   exec->pos = 0;
   exec->id = exec_find_free_id();
   exec->pid = 0;
-  if (name) exec->command = strdup(name);
-  else exec->command = NULL;
+  if (name)
+    exec->command = l_strdup(name);
+  else
+    exec->command = NULL;
 
   global.execs = g_list_append(global.execs, exec);
   return exec;
 }
 
-void exec_destroy(exec_t* exec) {
+void exec_destroy(exec_t * exec)
+{
   int status;
 
   waitpid(exec->pid, &status, WNOHANG);
@@ -76,52 +84,68 @@ void exec_destroy(exec_t* exec) {
     else
       client_message(_("Exec"), _("Process [%d] terminated"), exec->pid);
   }
-  if (exec->fd >= 0) close(exec->fd);
+  if (exec->fd >= 0)
+    close(exec->fd);
   if (strlen(exec->buf)) {
     exec_print_line(exec, exec->buf);
   }
-  
-  if (exec->input >= 0) gdk_input_remove(exec->input);
-  if (exec->command) free(exec->command);
-  
+
+  if (exec->input >= 0)
+    gdk_input_remove(exec->input);
+  if (exec->command)
+    l_free(exec->command);
+  if (exec->who)
+    l_free(exec->who);
+
   global.execs = g_list_remove(global.execs, exec);
 
-  free(exec);
+  l_free(exec);
 }
 
-char* exec_get_output(exec_t* exec) {
+char *exec_get_output(exec_t * exec)
+{
   static char result[1024];
 
   switch (exec->output) {
   case O_NONE:
-    sprintf(result, "[%s]", _("No Output")); break;
+    sprintf(result, "[%s]", _("No Output"));
+    break;
   case O_WINDOW:
-    sprintf(result, "[%s]", _("Window")); break;
+    sprintf(result, "[%s]", _("Window"));
+    break;
   case O_CHANNEL:
-    sprintf(result, "[%s:%s]", _("Channel"), exec->who); break;
+    sprintf(result, "[%s:%s]", _("Channel"), exec->who);
+    break;
   case O_PRIVATE:
-    sprintf(result, "[%s:%s]", _("Private"), exec->who); break;
+    sprintf(result, "[%s:%s]", _("Private"), exec->who);
+    break;
   case O_OPERATOR:
-    sprintf(result, "[%s:%s]", _("Channel op"), exec->who); break;
+    sprintf(result, "[%s:%s]", _("Channel op"), exec->who);
+    break;
   case O_GLOBAL:
-    sprintf(result, "[%s]", _("Global")); break;
+    sprintf(result, "[%s]", _("Global"));
+    break;
   case O_WALLOP:
-    sprintf(result, "[%s]", _("Wallop")); break;
+    sprintf(result, "[%s]", _("Wallop"));
+    break;
   default:
-    sprintf(result, "[%s]", _("Unknown")); break;
+    sprintf(result, "[%s]", _("Unknown"));
+    break;
   }
 
   return result;
 }
-void exec_list() {
-  GList* dlist;
-  exec_t* exec;
+
+void exec_list()
+{
+  GList *dlist;
+  exec_t *exec;
   char id[100];
 
   if (global.execs) {
     client_message(NULL, _("Lopster Process List:"));
     for (dlist = global.execs; dlist; dlist = dlist->next) {
-      exec = (exec_t*)(dlist->data);
+      exec = (exec_t *) (dlist->data);
       sprintf(id, "%2d", exec->id);
       client_message(id, "[%d] %s %s", exec->pid,
 		     exec_get_output(exec), exec->command);
@@ -131,35 +155,42 @@ void exec_list() {
   }
 }
 
-int exec_find_free_id() {
+int exec_find_free_id()
+{
   int id = 0;
-  GList* dlist;
-  exec_t* exec;
+  GList *dlist;
+  exec_t *exec;
 
   while (id < 1000) {
     for (dlist = global.execs; dlist; dlist = dlist->next) {
-      exec = (exec_t*)(dlist->data);
-      if (exec->id == id) break;
+      exec = (exec_t *) (dlist->data);
+      if (exec->id == id)
+	break;
     }
-    if (dlist) id++;
-    else return id;
+    if (dlist)
+      id++;
+    else
+      return id;
   }
   return -1;
 }
 
-exec_t* exec_find_id(int id) {
-  GList* dlist;
-  exec_t* exec;
+exec_t *exec_find_id(int id)
+{
+  GList *dlist;
+  exec_t *exec;
 
   for (dlist = global.execs; dlist; dlist = dlist->next) {
-    exec = (exec_t*)(dlist->data);
-    if (exec->id == id) return exec;
+    exec = (exec_t *) (dlist->data);
+    if (exec->id == id)
+      return exec;
   }
   return NULL;
 }
 
-void exec_kill(int id) {
-  exec_t* exec;
+void exec_kill(int id)
+{
+  exec_t *exec;
 
   exec = exec_find_id(id);
   if (!exec) {
@@ -173,39 +204,44 @@ void exec_kill(int id) {
   kill(exec->pid, SIGKILL);
 }
 
-void exec_kill_all() {
-  exec_t* exec;
-  GList* dlist;
+void exec_kill_all()
+{
+  exec_t *exec;
+  GList *dlist;
 
-  if (!global.execs) return;
+  if (!global.execs)
+    return;
 
   for (dlist = global.execs; dlist; dlist = dlist->next) {
-    exec = (exec_t*)(dlist->data);
+    exec = (exec_t *) (dlist->data);
     kill(exec->pid, SIGTERM);
   }
   sleep(2);
   for (dlist = global.execs; dlist; dlist = dlist->next) {
-    exec = (exec_t*)(dlist->data);
+    exec = (exec_t *) (dlist->data);
     kill(exec->pid, SIGKILL);
   }
 }
 
-void exec_fire_up(char* command, int output, char* who) {
-  int	p1[2], pid;
+void exec_fire_up(char *command, int output, char *who)
+{
+  int p1[2], pid;
   int i;
-  exec_t* exec;
+  exec_t *exec;
   gchar *argv[4];
 
   p1[0] = p1[1] = -1;
-  
+
   if (pipe(p1)) {
     client_message(NULL, _("Unable to start new process: %s"),
 		   strerror(errno));
-    if (p1[0] >= 0) close(p1[0]);
-    if (p1[1] >= 0) close(p1[1]);
+    if (p1[0] >= 0)
+      close(p1[0]);
+    if (p1[1] >= 0)
+      close(p1[1]);
     return;
   }
-  
+
   switch ((pid = fork())) {
   case -1:
     client_message(NULL, _("Couldn't start new process!"));
@@ -215,11 +251,12 @@ void exec_fire_up(char* command, int output, char* who) {
     setsid();
     setuid(getuid());
     setgid(getgid());
-    
-    dup2(p1[1], 1);  // copy stdout
+
+    dup2(p1[1], 1);		// copy stdout
     close(p1[0]);
     p1[0] = -1;
-    for (i = 3; i < 256; i++) close(i);
+    for (i = 3; i < 256; i++)
+      close(i);
 
     argv[0] = "sh";
     argv[1] = "-c";
@@ -232,17 +269,18 @@ void exec_fire_up(char* command, int output, char* who) {
     // parent
     close(p1[1]);
     p1[1] = -1;
-    
+
     exec = exec_new(command);
     exec->output = output;
     exec->pid = pid;
     exec->fd = p1[0];
-    if (who) exec->who = strdup(who);
-    
-    exec->input = 
-      gdk_input_add(exec->fd, GDK_INPUT_READ, 
+    if (who)
+      exec->who = l_strdup(who);
+
+    exec->input =
+      gdk_input_add(exec->fd, GDK_INPUT_READ,
 		    GTK_SIGNAL_FUNC(get_exec_input), exec);
-    
+
     break;
   }
 
@@ -253,11 +291,12 @@ void exec_fire_up(char* command, int output, char* who) {
   basic implementation by r00t
   added non blocking output read and more.
 */
-void exec_command(char* data) {
-  char* line;
-  char* command;
+void exec_command(char *data)
+{
+  char *line;
+  char *command;
   int output = O_WINDOW;
-  char* who = NULL;
+  char *who = NULL;
 
   line = arg(data, 1);
   if (!line) {
@@ -267,14 +306,18 @@ void exec_command(char* data) {
   if (!strncasecmp(line, "-out", 4)) {
     command = arg(line, 0);
     command = arg(NULL, 1);
-    if (in_channel()) {
+    if (global.current_page->type == P_PUBLIC) {
       output = O_CHANNEL;
       who = global.current_page->name;
-    } else if (in_private()) {
+    } else if (global.current_page->type == P_PRIVATE) {
       output = O_PRIVATE;
       who = global.current_page->name;
-    } else {
+    } else if (!strcmp("Wallop", global.current_page->name)) {
       output = O_WALLOP;
+    } else if (!strcmp("Global", global.current_page->name)) {
+      output = O_GLOBAL;
+    } else {
+      output = O_WINDOW;
     }
   } else if (!strncasecmp(line, "-msg", 4) ||
 	     !strncasecmp(line, "-whisper", 8)) {
@@ -311,8 +354,10 @@ void exec_command(char* data) {
       client_message(_("Error"), _("Kill what process?"));
       return;
     }
-    if (!strcasecmp(command, "all")) exec_kill_all();
-    else exec_kill(atoi(command));
+    if (!l_strcasecmp(command, "all"))
+      exec_kill_all();
+    else
+      exec_kill(atoi(command));
     return;
   } else if (*line == '-') {
     client_message(_("Error"), _("Unknown option!"));
@@ -329,19 +374,19 @@ void exec_command(char* data) {
   exec_fire_up(command, output, who);
 }
 
-gint get_exec_input(gpointer data, gint source, 
-		    GdkInputCondition condition) {
-  exec_t* exec = (exec_t*)data;
+gint get_exec_input(gpointer data, gint source,
+		    GdkInputCondition condition)
+{
+  exec_t *exec = (exec_t *) data;
   int res;
-  char* pos1;
-  char* pos2;
+  char *pos1;
+  char *pos2;
 
   if (condition != GDK_INPUT_READ) {
     exec_destroy(exec);
     return 0;
   }
-  switch (res = read(source, exec->buf+exec->pos, 
-		     2047-exec->pos-1)) {
+  switch (res = read(source, exec->buf + exec->pos, 2048 - exec->pos - 1)) {
   case -1:
     exec_destroy(exec);
     return 0;
@@ -352,13 +397,13 @@ gint get_exec_input(gpointer data, gint source,
     break;
   }
 
-  exec->buf[res+exec->pos] = 0;
+  exec->buf[res + exec->pos] = 0;
 
   pos1 = exec->buf;
   while ((pos2 = strchr(pos1, '\n')) || (pos2 = strchr(pos1, '\r'))) {
     *pos2 = 0;
     exec_print_line(exec, pos1);
-    pos1 = pos2+1;
+    pos1 = pos2 + 1;
   }
 
   strcpy(exec->buf, pos1);
@@ -366,7 +411,8 @@ gint get_exec_input(gpointer data, gint source,
   return 0;
 }
 
-void exec_print_line(exec_t* exec, char* line) {
+void exec_print_line(exec_t * exec, char *line)
+{
   switch (exec->output) {
   case O_NONE:
     break;
