@@ -1,3 +1,7 @@
+/* Copyright (C) 2000/2001 sgop@users.sourceforge.net
+   This is free software distributed under the terms of the
+   GNU Public License.  See the file COPYING for details. */
+
 #define CMD_VERSION_CHECK               4
 #define CMD_AUTO_UPGRADE                5
 #define CMD_HOTLIST_ERROR               302
@@ -159,16 +163,16 @@
 #define CMD_CLIENT_USAGE_STATS		10115	/* server usage stats */
 #define CMD_SERVER_USAGE_STATS		10115
 #define CMD_CLIENT_REHASH		10117	/* reload config file */
-#define CMD_CLIENT_VERSION_STATS        10118   /* client version stats */
-#define CMD_CLIENT_WHICH_SERVER         10119   /* which server a user is on */
+#define CMD_CLIENT_VERSION_STATS        10118	/* client version stats */
+#define CMD_CLIENT_WHICH_SERVER         10119	/* which server a user is on */
 #define CMD_CLIENT_PING_ALL_SERVERS     10120
 #define CMD_CLIENT_WHO_WAS              10121
 #define CMD_CLIENT_MASS_KILL            10122
 #define CMD_CLIENT_HISTOGRAM		10123
 #define CMD_SERVER_HISTOGRAM		10124
 #define CMD_CLIENT_REGISTER_USER	10200
-#define CMD_CLIENT_CHANNEL_LEVEL	10201	/* deprecated, use 823 instead*/
-#define CMD_CLIENT_KICK_USER		10202	/* deprecated, use 829 instead*/
+#define CMD_CLIENT_CHANNEL_LEVEL	10201	/* deprecated, use 823 instead */
+#define CMD_CLIENT_KICK_USER		10202	/* deprecated, use 829 instead */
 #define CMD_CLIENT_USER_MODE		10203	/* set a user mode */
 #define CMD_SERVER_USER_MODE		10203
 #define CMD_CLIENT_OP			10204
@@ -201,15 +205,17 @@ extern char Mode[NO_MODES][20];
 
 #define HANDLER(f) void f (char *data)
 
-typedef struct {
+typedef struct
+{
   int code;
-  HANDLER ((*handler));
-} HANDLER_ENTRY;
+  HANDLER((*handler));
+}
+HANDLER_ENTRY;
 
-int mode2int(char* mode);
-void not_implemented(int type, char* data);
+int mode2int(char *mode);
+void not_implemented(int type, char *data);
 int search_handler(int code);
-void handle_command(int type, char* data);
+void handle_command(int type, char *data);
 
 HANDLER(cmd_do_nothing);
 HANDLER(cmd_server_error);
@@ -235,7 +241,7 @@ HANDLER(cmd_unignore_user);
 HANDLER(cmd_part_channel);
 HANDLER(cmd_public_message);
 HANDLER(cmd_error_message);
-HANDLER(cmd_create_channel );
+HANDLER(cmd_create_channel);
 HANDLER(cmd_join_message);
 HANDLER(cmd_part_message);
 HANDLER(cmd_user_online);
