@@ -1,3 +1,7 @@
+/* Copyright (C) 2000/2001 sgop@users.sourceforge.net
+   This is free software distributed under the terms of the
+   GNU Public License.  See the file COPYING for details. */
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -44,11 +48,12 @@
 #include "preferences.h"
 #include "log.h"
 #include "wizard.h"
+#include "string_list.h"
 
 #define PAGES   5
 
 int page;
-GtkWidget* win;
+GtkWidget *win;
 int browse_mime;
 
 void wizard_setup_page();
@@ -56,11 +61,12 @@ void wizard_print_help();
 void wizard_apply_current();
 int wizard_check_current();
 
-void wizard_start() {
-  GtkWidget* temp;
+void wizard_start()
+{
+  GtkWidget *temp;
 
   win = create_wizard();
-  
+
   temp = lookup_widget(win, "label754");
   gtk_widget_set_style(temp, global.style[STYLE_PREF]);
 
@@ -74,16 +80,17 @@ void wizard_start() {
   gtk_widget_set_style(temp, global.style[STYLE_LABEL]);
   temp = lookup_widget(win, "label765");
   gtk_widget_set_style(temp, global.style[STYLE_LABEL]);
-  
+
   page = 1;
   wizard_setup_page();
 
   gtk_my_widget_show(win);
 }
 
-void wizard_setup_page() {
-  GtkWidget* temp;
-  GtkButton* button;
+void wizard_setup_page()
+{
+  GtkWidget *temp;
+  GtkButton *button;
 
   temp = lookup_widget(win, "label754");
   switch (page) {
@@ -105,18 +112,23 @@ void wizard_setup_page() {
   }
 
   temp = lookup_widget(win, "button246");
-  if (page == 1) gtk_widget_set_sensitive(temp, FALSE);
-  else gtk_widget_set_sensitive(temp, TRUE);
+  if (page == 1)
+    gtk_widget_set_sensitive(temp, FALSE);
+  else
+    gtk_widget_set_sensitive(temp, TRUE);
 
   button = GTK_BUTTON(lookup_widget(win, "button247"));
-  if (page == PAGES) gtk_label_set_text(GTK_LABEL(button->child), "Finish");
-  else gtk_label_set_text(GTK_LABEL(button->child), "Next ->");
+  if (page == PAGES)
+    gtk_label_set_text(GTK_LABEL(button->child), "Finish");
+  else
+    gtk_label_set_text(GTK_LABEL(button->child), "Next ->");
 
   wizard_print_help();
 }
 
-void wizard_previous() {
-  GtkWidget* temp;
+void wizard_previous()
+{
+  GtkWidget *temp;
 
   temp = lookup_widget(win, "notebook7");
 
@@ -126,16 +138,18 @@ void wizard_previous() {
     gtk_notebook_prev_page(GTK_NOTEBOOK(temp));
     page--;
   }
-  
+
   wizard_setup_page();
 }
 
-void wizard_next() {
-  GtkWidget* temp;
+void wizard_next()
+{
+  GtkWidget *temp;
 
   temp = lookup_widget(win, "notebook7");
 
-  if (!wizard_check_current()) return;
+  if (!wizard_check_current())
+    return;
   wizard_apply_current();
 
   if (page < PAGES) {
@@ -147,11 +161,11 @@ void wizard_next() {
   }
 }
 
-void wizard_finish() {
-  server_t* server;
+void wizard_finish()
+{
+  server_t *server;
 
-  global.channels = 
-    g_list_append(global.channels, strdup("Lopster"));
+  autojoin_add("Lopster");
 
   server = server_new();
   server_set_address(server, "server.napster.com");
@@ -163,7 +177,7 @@ void wizard_finish() {
   server_set_nick(server, global.user.username);
   server_set_passwd(server, global.user.password);
   add_server_to_list(server);
-  
+
   server = server_new();
   server_set_address(server, "server5.dtype.org");
   server->port = 8888;
@@ -174,14 +188,15 @@ void wizard_finish() {
   server_set_nick(server, global.user.username);
   server_set_passwd(server, global.user.password);
   add_server_to_list(server);
-  
+
   command_make_alias("msg", "whisper");
   command_make_alias("join", "j");
   command_make_alias("part", "p");
   command_make_alias("me", "emote");
   command_make_alias("away", "afk");
 
-  if (global.incomplete_path) create_dir(global.incomplete_path);
+  if (global.incomplete_path)
+    create_dir(global.incomplete_path);
 
   write_rc();
   lib_refresh();
@@ -189,24 +204,29 @@ void wizard_finish() {
   gtk_widget_destroy(win);
 }
 
-int wizard_check_current() {
-  GtkWidget* temp;
-  char* text;
-  char* text2;
+int wizard_check_current()
+{
+  GtkWidget *temp;
+  char *text;
+  char *text2;
 
   switch (page) {
   case 1:
     temp = lookup_widget(win, "entry86");
     text = gtk_entry_get_text(GTK_ENTRY(temp));
-    if (strlen(text) < 2) return 0;
-    if (strchr(text, ' ')) return 0;
+    if (strlen(text) < 2)
+      return 0;
+    if (strchr(text, ' '))
+      return 0;
 
     temp = lookup_widget(win, "entry87");
     text = gtk_entry_get_text(GTK_ENTRY(temp));
     temp = lookup_widget(win, "entry88");
     text2 = gtk_entry_get_text(GTK_ENTRY(temp));
-    if (strcmp(text, text2)) return 0;
-    if (strchr(text, ' ')) return 0;
+    if (strcmp(text, text2))
+      return 0;
+    if (strchr(text, ' '))
+      return 0;
     return 1;
     break;
   case 2:
@@ -218,8 +238,10 @@ int wizard_check_current() {
     text = gtk_entry_get_text(GTK_ENTRY(temp));
     temp = lookup_widget(win, "entry91");
     text2 = gtk_entry_get_text(GTK_ENTRY(temp));
-    if (strlen(text) < 1) return 0;
-    if (strlen(text2) < 1) return 0;
+    if (strlen(text) < 1)
+      return 0;
+    if (strlen(text2) < 1)
+      return 0;
     return 1;
     break;
   case 5:
@@ -230,11 +252,12 @@ int wizard_check_current() {
   return 1;
 }
 
-void wizard_apply_current() {
-  GtkWidget* temp;
-  char* text;
-  char* text2;
-  suffix_t* suffix;
+void wizard_apply_current()
+{
+  GtkWidget *temp;
+  char *text;
+  char *text2;
+  suffix_t *suffix;
   int mime, i1;
 
   switch (page) {
@@ -253,7 +276,8 @@ void wizard_apply_current() {
     temp = lookup_widget(win, "checkbutton67");
     if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(temp))) {
       global.network.firewall = 1;
-    } else global.network.firewall = 0;
+    } else
+      global.network.firewall = 0;
     temp = lookup_widget(win, "spinbutton57");
     i1 = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(temp));
     create_upload_port(i1, TRUE);
@@ -261,146 +285,149 @@ void wizard_apply_current() {
   case 3:
     clear_suffixes();
     temp = lookup_widget(win, "entry99");
-    text = strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
+    text = l_strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
     text2 = arg(text, 0);
     while (text2) {
-      suffix = (suffix_t*)malloc(sizeof(suffix_t));
-      suffix->suffix = strdup(text2);
-      suffix->application = strdup("");
+      suffix = (suffix_t *) malloc(sizeof(suffix_t));
+      suffix->suffix = l_strdup(text2);
+      suffix->application = l_strdup("");
       suffix->as_mp3 = 1;
       global.mimetype[MIME_MP3].suffixes =
-	g_list_append(global.mimetype[MIME_MP3].suffixes, suffix);
+	  g_list_append(global.mimetype[MIME_MP3].suffixes, suffix);
       text2 = arg(NULL, 0);
     }
-    free(text);
+    l_free(text);
     temp = lookup_widget(win, "entry100");
-    text = strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
+    text = l_strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
     text2 = arg(text, 0);
     while (text2) {
-      suffix = (suffix_t*)malloc(sizeof(suffix_t));
-      suffix->suffix = strdup(text2);
-      suffix->application = strdup("");
+      suffix = (suffix_t *) malloc(sizeof(suffix_t));
+      suffix->suffix = l_strdup(text2);
+      suffix->application = l_strdup("");
       suffix->as_mp3 = 0;
       global.mimetype[MIME_VIDEO].suffixes =
-	g_list_append(global.mimetype[MIME_VIDEO].suffixes, suffix);
+	  g_list_append(global.mimetype[MIME_VIDEO].suffixes, suffix);
       text2 = arg(NULL, 0);
     }
-    free(text);
+    l_free(text);
     temp = lookup_widget(win, "entry101");
-    text = strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
+    text = l_strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
     text2 = arg(text, 0);
     while (text2) {
-      suffix = (suffix_t*)malloc(sizeof(suffix_t));
-      suffix->suffix = strdup(text2);
-      suffix->application = strdup("");
+      suffix = (suffix_t *) malloc(sizeof(suffix_t));
+      suffix->suffix = l_strdup(text2);
+      suffix->application = l_strdup("");
       suffix->as_mp3 = 0;
       global.mimetype[MIME_AUDIO].suffixes =
-	g_list_append(global.mimetype[MIME_AUDIO].suffixes, suffix);
+	  g_list_append(global.mimetype[MIME_AUDIO].suffixes, suffix);
       text2 = arg(NULL, 0);
     }
-    free(text);
+    l_free(text);
     temp = lookup_widget(win, "entry102");
-    text = strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
+    text = l_strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
     text2 = arg(text, 0);
     while (text2) {
-      suffix = (suffix_t*)malloc(sizeof(suffix_t));
-      suffix->suffix = strdup(text2);
-      suffix->application = strdup("");
+      suffix = (suffix_t *) malloc(sizeof(suffix_t));
+      suffix->suffix = l_strdup(text2);
+      suffix->application = l_strdup("");
       suffix->as_mp3 = 0;
       global.mimetype[MIME_APPLICATION].suffixes =
-	g_list_append(global.mimetype[MIME_APPLICATION].suffixes, suffix);
+	  g_list_append(global.mimetype[MIME_APPLICATION].suffixes,
+			suffix);
       text2 = arg(NULL, 0);
     }
-    free(text);
+    l_free(text);
     temp = lookup_widget(win, "entry103");
-    text = strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
+    text = l_strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
     text2 = arg(text, 0);
     while (text2) {
-      suffix = (suffix_t*)malloc(sizeof(suffix_t));
-      suffix->suffix = strdup(text2);
-      suffix->application = strdup("");
+      suffix = (suffix_t *) malloc(sizeof(suffix_t));
+      suffix->suffix = l_strdup(text2);
+      suffix->application = l_strdup("");
       suffix->as_mp3 = 0;
       global.mimetype[MIME_IMAGE].suffixes =
-	g_list_append(global.mimetype[MIME_IMAGE].suffixes, suffix);
+	  g_list_append(global.mimetype[MIME_IMAGE].suffixes, suffix);
       text2 = arg(NULL, 0);
     }
-    free(text);
+    l_free(text);
     temp = lookup_widget(win, "entry104");
-    text = strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
+    text = l_strdup(gtk_entry_get_text(GTK_ENTRY(temp)));
     text2 = arg(text, 0);
     while (text2) {
-      suffix = (suffix_t*)malloc(sizeof(suffix_t));
-      suffix->suffix = strdup(text2);
-      suffix->application = strdup("");
+      suffix = (suffix_t *) malloc(sizeof(suffix_t));
+      suffix->suffix = l_strdup(text2);
+      suffix->application = l_strdup("");
       suffix->as_mp3 = 0;
       global.mimetype[MIME_TEXT].suffixes =
-	g_list_append(global.mimetype[MIME_TEXT].suffixes, suffix);
+	  g_list_append(global.mimetype[MIME_TEXT].suffixes, suffix);
       text2 = arg(NULL, 0);
     }
-    free(text);
+    l_free(text);
     break;
   case 4:
     temp = lookup_widget(win, "entry90");
     text = gtk_entry_get_text(GTK_ENTRY(temp));
-    if (global.incomplete_path) free(global.incomplete_path);
-    global.incomplete_path = strdup(text);
+    if (global.incomplete_path)
+      l_free(global.incomplete_path);
+    global.incomplete_path = l_strdup(text);
     temp = lookup_widget(win, "entry91");
     text = gtk_entry_get_text(GTK_ENTRY(temp));
     if (global.mimetype[MIME_MP3].download)
-      free(global.mimetype[MIME_MP3].download);
-    global.mimetype[MIME_MP3].download = strdup(text);
+      l_free(global.mimetype[MIME_MP3].download);
+    global.mimetype[MIME_MP3].download = l_strdup(text);
     temp = lookup_widget(win, "entry92");
     text = gtk_entry_get_text(GTK_ENTRY(temp));
     if (global.mimetype[MIME_VIDEO].download)
-      free(global.mimetype[MIME_VIDEO].download);
-    global.mimetype[MIME_VIDEO].download = strdup(text);
+      l_free(global.mimetype[MIME_VIDEO].download);
+    global.mimetype[MIME_VIDEO].download = l_strdup(text);
     temp = lookup_widget(win, "entry93");
     text = gtk_entry_get_text(GTK_ENTRY(temp));
     if (global.mimetype[MIME_AUDIO].download)
-      free(global.mimetype[MIME_AUDIO].download);
-    global.mimetype[MIME_AUDIO].download = strdup(text);
+      l_free(global.mimetype[MIME_AUDIO].download);
+    global.mimetype[MIME_AUDIO].download = l_strdup(text);
     temp = lookup_widget(win, "entry94");
     text = gtk_entry_get_text(GTK_ENTRY(temp));
     if (global.mimetype[MIME_APPLICATION].download)
-      free(global.mimetype[MIME_APPLICATION].download);
-    global.mimetype[MIME_APPLICATION].download = strdup(text);
+      l_free(global.mimetype[MIME_APPLICATION].download);
+    global.mimetype[MIME_APPLICATION].download = l_strdup(text);
     temp = lookup_widget(win, "entry95");
     text = gtk_entry_get_text(GTK_ENTRY(temp));
     if (global.mimetype[MIME_IMAGE].download)
-      free(global.mimetype[MIME_IMAGE].download);
-    global.mimetype[MIME_IMAGE].download = strdup(text);
+      l_free(global.mimetype[MIME_IMAGE].download);
+    global.mimetype[MIME_IMAGE].download = l_strdup(text);
     temp = lookup_widget(win, "entry96");
     text = gtk_entry_get_text(GTK_ENTRY(temp));
     if (global.mimetype[MIME_TEXT].download)
-      free(global.mimetype[MIME_TEXT].download);
-    global.mimetype[MIME_TEXT].download = strdup(text);
+      l_free(global.mimetype[MIME_TEXT].download);
+    global.mimetype[MIME_TEXT].download = l_strdup(text);
     temp = lookup_widget(win, "entry97");
     text = gtk_entry_get_text(GTK_ENTRY(temp));
     if (global.mimetype[MIME_NONE].download)
-      free(global.mimetype[MIME_NONE].download);
-    global.mimetype[MIME_NONE].download = strdup(text);
+      l_free(global.mimetype[MIME_NONE].download);
+    global.mimetype[MIME_NONE].download = l_strdup(text);
     break;
   case 5:
     clear_shared_folder();
     temp = lookup_widget(win, "clist22");
     for (i1 = 0; i1 < GTK_CLIST(temp)->rows; i1++) {
-      gtk_clist_get_text (GTK_CLIST(temp), i1, 0, &text);
+      gtk_clist_get_text(GTK_CLIST(temp), i1, 0, &text);
       mime = mime2int(text);
-      gtk_clist_get_text (GTK_CLIST(temp), i1, 1, &text);
-      text2 = strdup(text);
-      if (text2[strlen(text2)-1] == '/')
-	text2[strlen(text2)-1] = 0;
-      global.mimetype[mime].shared = 
-	g_list_append(global.mimetype[mime].shared, text2);
+      gtk_clist_get_text(GTK_CLIST(temp), i1, 1, &text);
+      text2 = l_strdup(text);
+      if (text2[strlen(text2) - 1] == '/')
+	text2[strlen(text2) - 1] = 0;
+      global.mimetype[mime].shared =
+	  g_list_append(global.mimetype[mime].shared, text2);
     }
     break;
   }
 }
 
-void wizard_help() {
-  GtkWidget* temp;
-  GtkButton* button;
-  
+void wizard_help()
+{
+  GtkWidget *temp;
+  GtkButton *button;
+
   temp = lookup_widget(win, "frame276");
   button = GTK_BUTTON(lookup_widget(win, "button264"));
 
@@ -413,130 +440,138 @@ void wizard_help() {
   }
 }
 
-void wizard_print_help() {
-  GtkWidget* temp;
+void wizard_print_help()
+{
+  GtkWidget *temp;
 
   temp = lookup_widget(win, "label781");
   switch (page) {
   case 1:
     gtk_label_set_text(GTK_LABEL(temp),
-		       _("Just enter a username and a password, make sure that you do not include spaces!"));
+		       _
+		       ("Just enter a username and a password, make sure that you do not include spaces!"));
     break;
   case 2:
     gtk_label_set_text(GTK_LABEL(temp),
-		       _("The specified linespeed will be shown to others, if they request your information. It is not important to select the correct speed, but it would be fair to the others.\nYou may set the dataport to every port that is reachable for the rest of the world, if there is no such port (firewalled), then select 0 instead."));
+		       _
+		       ("The specified linespeed will be shown to others, if they request your information. It is not important to select the correct speed, but it would be fair to the others.\nYou may set the dataport to every port that is reachable for the rest of the world, if there is no such port (firewalled), then select 0 instead."));
     break;
   case 3:
     gtk_label_set_text(GTK_LABEL(temp),
-		       _("This are the file suffixes that will be known by Lopster. You can bind each of them to an external application in the preferences later."));
+		       _
+		       ("This are the file suffixes that will be known by Lopster. You can bind each of them to an external application in the preferences later."));
     break;
   case 4:
     gtk_label_set_text(GTK_LABEL(temp),
-		       _("Lopster needs to know where it should store the downloaded files. While downloading they will be saved in the incomplete Folder, when finished they will be moved to the folder according to its suffix. At least setup the folder for incomplete files and MP3 files."));
+		       _
+		       ("Lopster needs to know where it should store the downloaded files. While downloading they will be saved in the incomplete Folder, when finished they will be moved to the folder according to its suffix. At least setup the folder for incomplete files and MP3 files."));
     break;
   case 5:
     gtk_label_set_text(GTK_LABEL(temp),
-		       _("Setup your shared library here. Lopster will scan the specified directories recursively for files that are known (section Suffixes)."));
+		       _
+		       ("Setup your shared library here. Lopster will scan the specified directories recursively for files that are known (section Suffixes)."));
     break;
   }
 }
 
-void on_wizard_dir_select2(gchar* dir) {
-  GtkWidget* temp;
-  
+void on_wizard_dir_select2(gchar * dir)
+{
+  GtkWidget *temp;
+
   temp = lookup_widget(win, "clist22");
   strcpy(list[0], MimeNames(browse_mime));
   strcpy(list[1], dir);
-  if (list[1][strlen(list[1])-1] == '/')
-    list[1][strlen(list[1])-1] = 0;
+  if (list[1][strlen(list[1]) - 1] == '/')
+    list[1][strlen(list[1]) - 1] = 0;
   gtk_clist_append(GTK_CLIST(temp), list);
 }
 
-void on_folder_add (GtkMenuItem *menuitem, gpointer user_data) {
-  GtkWidget* win;
-  
-  browse_mime = (int)user_data;
-  win = create_dir_browser(_("Select Directory"), NULL, 
+void on_folder_add(GtkMenuItem * menuitem ATTR_UNUSED, gpointer user_data)
+{
+  GtkWidget *win;
+
+  browse_mime = (int) user_data;
+  win = create_dir_browser(_("Select Directory"), g_get_home_dir(),
 			   GTK_SELECTION_SINGLE, on_wizard_dir_select2);
   gtk_widget_show(win);
 }
 
-GtkWidget* create_wizard_popup() {
+GtkWidget *create_wizard_popup()
+{
   GtkWidget *popup;
   GtkAccelGroup *popup_accels;
   GtkWidget *item;
 
-  popup = gtk_menu_new ();
-  gtk_object_set_data (GTK_OBJECT (popup), "popup", popup);
-  popup_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (popup));
+  popup = gtk_menu_new();
+  gtk_object_set_data(GTK_OBJECT(popup), "popup", popup);
+  popup_accels = gtk_menu_ensure_uline_accel_group(GTK_MENU(popup));
 
-  item = gtk_menu_item_new_with_label (_("MP3"));
-  gtk_widget_show (item);
-  gtk_container_add (GTK_CONTAINER (popup), item);
-  gtk_signal_connect (GTK_OBJECT (item), "activate",
-                      GTK_SIGNAL_FUNC (on_folder_add),
-                      (gpointer)MIME_MP3);
+  item = gtk_menu_item_new_with_label(_("MP3"));
+  gtk_widget_show(item);
+  gtk_container_add(GTK_CONTAINER(popup), item);
+  gtk_signal_connect(GTK_OBJECT(item), "activate",
+		     GTK_SIGNAL_FUNC(on_folder_add), (gpointer) MIME_MP3);
 
-  item = gtk_menu_item_new_with_label (_("Video"));
-  gtk_widget_show (item);
-  gtk_container_add (GTK_CONTAINER (popup), item);
-  gtk_signal_connect (GTK_OBJECT (item), "activate",
-                      GTK_SIGNAL_FUNC (on_folder_add),
-                      (gpointer)MIME_VIDEO);
+  item = gtk_menu_item_new_with_label(_("Video"));
+  gtk_widget_show(item);
+  gtk_container_add(GTK_CONTAINER(popup), item);
+  gtk_signal_connect(GTK_OBJECT(item), "activate",
+		     GTK_SIGNAL_FUNC(on_folder_add),
+		     (gpointer) MIME_VIDEO);
 
-  item = gtk_menu_item_new_with_label (_("Audio"));
-  gtk_widget_show (item);
-  gtk_container_add (GTK_CONTAINER (popup), item);
-  gtk_signal_connect (GTK_OBJECT (item), "activate",
-                      GTK_SIGNAL_FUNC (on_folder_add),
-                      (gpointer)MIME_AUDIO);
+  item = gtk_menu_item_new_with_label(_("Audio"));
+  gtk_widget_show(item);
+  gtk_container_add(GTK_CONTAINER(popup), item);
+  gtk_signal_connect(GTK_OBJECT(item), "activate",
+		     GTK_SIGNAL_FUNC(on_folder_add),
+		     (gpointer) MIME_AUDIO);
 
-  item = gtk_menu_item_new_with_label (_("Application"));
-  gtk_widget_show (item);
-  gtk_container_add (GTK_CONTAINER (popup), item);
-  gtk_signal_connect (GTK_OBJECT (item), "activate",
-                      GTK_SIGNAL_FUNC (on_folder_add),
-                      (gpointer)MIME_APPLICATION);
+  item = gtk_menu_item_new_with_label(_("Application"));
+  gtk_widget_show(item);
+  gtk_container_add(GTK_CONTAINER(popup), item);
+  gtk_signal_connect(GTK_OBJECT(item), "activate",
+		     GTK_SIGNAL_FUNC(on_folder_add),
+		     (gpointer) MIME_APPLICATION);
 
-  item = gtk_menu_item_new_with_label (_("Image"));
-  gtk_widget_show (item);
-  gtk_container_add (GTK_CONTAINER (popup), item);
-  gtk_signal_connect (GTK_OBJECT (item), "activate",
-                      GTK_SIGNAL_FUNC (on_folder_add),
-                      (gpointer)MIME_IMAGE);
+  item = gtk_menu_item_new_with_label(_("Image"));
+  gtk_widget_show(item);
+  gtk_container_add(GTK_CONTAINER(popup), item);
+  gtk_signal_connect(GTK_OBJECT(item), "activate",
+		     GTK_SIGNAL_FUNC(on_folder_add),
+		     (gpointer) MIME_IMAGE);
 
-  item = gtk_menu_item_new_with_label (_("Text"));
-  gtk_widget_show (item);
-  gtk_container_add (GTK_CONTAINER (popup), item);
-  gtk_signal_connect (GTK_OBJECT (item), "activate",
-                      GTK_SIGNAL_FUNC (on_folder_add),
-                      (gpointer)MIME_TEXT);
+  item = gtk_menu_item_new_with_label(_("Text"));
+  gtk_widget_show(item);
+  gtk_container_add(GTK_CONTAINER(popup), item);
+  gtk_signal_connect(GTK_OBJECT(item), "activate",
+		     GTK_SIGNAL_FUNC(on_folder_add), (gpointer) MIME_TEXT);
 
-  item = gtk_menu_item_new_with_label (_("Any Files"));
-  gtk_widget_show (item);
-  gtk_container_add (GTK_CONTAINER (popup), item);
-  gtk_signal_connect (GTK_OBJECT (item), "activate",
-                      GTK_SIGNAL_FUNC (on_folder_add),
-                      (gpointer)MIME_NONE);
+  item = gtk_menu_item_new_with_label(_("Any Files"));
+  gtk_widget_show(item);
+  gtk_container_add(GTK_CONTAINER(popup), item);
+  gtk_signal_connect(GTK_OBJECT(item), "activate",
+		     GTK_SIGNAL_FUNC(on_folder_add), (gpointer) MIME_NONE);
 
   return popup;
 }
 
-void wizard_clear_selected() {
-  GtkCList* clist;
-  GList* row_list;
+void wizard_clear_selected()
+{
+  GtkCList *clist;
+  GList *row_list;
   int row;
 
   clist = GTK_CLIST(lookup_widget(win, "clist22"));
   while ((row_list = clist->selection) != NULL) {
-    row = (int)row_list->data;
+    row = (int) row_list->data;
     gtk_clist_remove(clist, row);
   }
 }
 
-void on_wizard_dir_select(gchar* dir) {
-  GtkWidget* temp;
-  gchar* dir2;
+void on_wizard_dir_select(gchar * dir)
+{
+  GtkWidget *temp;
+  gchar *dir2;
 
   switch (browse_mime) {
   case 0:
@@ -567,17 +602,18 @@ void on_wizard_dir_select(gchar* dir) {
     return;
   }
 
-  dir2 = strdup(dir);
-  if (dir2[strlen(dir2)-1] == '/')
-    dir2[strlen(dir2)-1] = 0;
+  dir2 = l_strdup(dir);
+  if (dir2[strlen(dir2) - 1] == '/')
+    dir2[strlen(dir2) - 1] = 0;
   gtk_entry_set_text(GTK_ENTRY(temp), dir2);
 }
 
-void wizard_browse(int mime) {
-  GtkWidget* win;
-  
+void wizard_browse(int mime)
+{
+  GtkWidget *win;
+
   browse_mime = mime;
-  win = create_dir_browser(_("Select Directory"), NULL, 
+  win = create_dir_browser(_("Select Directory"), g_get_home_dir(),
 			   GTK_SELECTION_SINGLE, on_wizard_dir_select);
   gtk_widget_show(win);
 }
